{ pkgs, lib, ... }:
{
  custom.home_wg_suffix = "2";
  system.autoUpgrade.allowReboot = lib.mkForce false;

  networking = {
    wg-quick.interfaces = {
      wg1 = {
        autostart = false;
        address = [ "10.100.0.7/24" ];
        dns = [ "1.1.1.1" ];
        privateKeyFile = "/persist/secrets/wireguard/priv-netflix";
        listenPort = 51820;

        peers = [
          {
            publicKey = "XSYHg0utIR1j7kRsWFwuWNo4RPD47KP53cVa6qDPtRE=";
            allowedIPs = [
              "0.0.0.0/0"
              "192.168.0.0/24"
            ];
            endpoint = "netflix.vsinerva.fi:51821";
          }
        ];
      };
    };
  };

  services.xserver.displayManager.setupCommands = ''
    ${pkgs.xorg.xrandr}/bin/xrandr --output DP-1 --auto --pos 0x0 --primary --output eDP-1 --auto --pos 3840x360
  '';

  imports = [
    ../../shared/base.nix

    ../../personal/desktop.nix
    ../../personal/development.nix

    ../../personal/hardware/amd-laptop.nix
    ../../personal/hardware/hibernate.nix
    ../../personal/hardware/keychron-q11.nix
    ../../personal/hardware/onlykey.nix
    ../../personal/hardware/trackball.nix

    ../../personal/networking/home-wg.nix
    ../../personal/networking/printing.nix

    ../../personal/programs/bitwarden.nix
    ../../personal/programs/communication.nix
    ../../personal/programs/firefox.nix
    ../../personal/programs/i3.nix
    ../../personal/programs/moonlight.nix
    ../../personal/programs/redshift.nix
    ../../personal/programs/study.nix
    ../../personal/programs/usb-automount.nix

    ../../servers/syncthing.nix
  ];
}
