{ pkgs, ... }:
{
  imports = [
    ./programs/symlinked/symlinks.nix
    ../shared/users/vili.nix
  ];

  environment.systemPackages = with pkgs; [
    alacritty
    vlc
    flameshot
    speedcrunch
  ];

  services = {
    displayManager = {
      autoLogin.enable = true;
      autoLogin.user = "vili";
    };
    xserver = {
      enable = true;
      displayManager = {
        lightdm.enable = true;
        sessionCommands = ''${pkgs.xorg.xrdb}/bin/xrdb -merge < ${
          (import ./programs/embedded/xresources.nix { inherit pkgs; })
        }'';
      };
    };

    pipewire.enable = false;
    pulseaudio.enable = true;
  };
  nixpkgs.config.pulseaudio = true;

  security.polkit.enable = true;

  xdg.mime.defaultApplications = {
    "application/pdf" = "org.gnome.Evince.desktop";
    "text/plain" = "org.xfce.mousepad.desktop";
    "text/x-tex" = "org.kde.kile.desktop";
    "inode/directory" = "pcmanfm.description";
  };

  qt = {
    enable = true;
    style = "adwaita-dark";
    platformTheme = "gnome";
  };
}
